% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BOLL-G.R
\name{BOLLG}
\alias{BOLLG}
\alias{pbollg}
\alias{dbollg}
\alias{qbollg}
\alias{rbollg}
\alias{hbollg}
\title{The beta Odd log-logistic family of distributions (BOLL-G)}
\usage{
pbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)

dbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)

qbollg(q, alpha = 1, a = 1, b = 1, G = pnorm, ...)

rbollg(n, alpha = 1, a = 1, b = 1, G = pnorm, ...)

hbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)
}
\arguments{
\item{x}{scaler or vector of values at which the pdf or cdf needs to be computed.}

\item{alpha}{the value of the first shape parameter, must be positive, the default is 1.}

\item{a}{the value of the shape parameter, must be positive, the default is 1.}

\item{b}{the value of the shape parameter, must be positive, the default is 1.}

\item{G}{A baseline continuous cdf.}

\item{...}{The baseline cdf parameters.}

\item{q}{scaler or vector of probabilities at which the quantile needs to be computed.}

\item{n}{number of random numbers to be generated.}
}
\value{
\code{pbollg} gives the distribution function,
 \code{dbollg} gives the density,
 \code{qbollg} gives the quantile function,
 \code{hbollg} gives the hazard function and
 \code{rbollg} generates random variables from the The beta Odd log-logistic family of
 distributions (BOLL-G) for baseline cdf G.
}
\description{
Computes the pdf, cdf, hdf, quantile and random numbers
of the beta extended distribution due to Cordeiro et al. (2016) specified by the pdf
\deqn{f=\frac{\alpha\,g\,G^{a\,\alpha-1}\bar{G}^{b\,\alpha-1}}{B(a,b)[G^\alpha+\bar{G}^\alpha]^{a+b}}}
for \eqn{G} any valid continuous cdf , \eqn{\bar{G}=1-G}, \eqn{g} the corresponding pdf, \eqn{B(a, b)}, the beta function, \eqn{a, b > 0}, the shape parameter, \eqn{\alpha > 0}, the first shape parameter.
}
\examples{
x <- seq(0, 1, length.out = 21)
pbollg(x)
pbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2)
dbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2)
curve(dbollg, -3, 3)
qbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2)
n <- 10
rbollg(n, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2)
hbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2)
curve(hbollg, -3, 3)
}
\references{
Cordeiro, G. M., Alizadeh, M., Tahir, M. H., Mansoor, M., Bourguignon, M., Hamedani, G. G. (2016). The beta odd log-logistic generalized family of distributions. Hacettepe Journal of Mathematics and Statistics, 45(4), 1175-1202.
}
